@@ -1,4 +1,4 @@
-/* Copyright 2022 VMware, Inc.
+/* Copyright 2023 VMware, Inc.
  * SPDX-License-Identifier: Apache-2.0
  */
 #pragma once
@@ -49,32 +49,35 @@ void key_file_free(KeyFile *k);
 DEFINE_CLEANUP(KeyFile*, key_file_free);
 
 int config_manager_new(const Config *configs, ConfigManager **ret);
-void config_manager_unref(ConfigManager *m);
-DEFINE_CLEANUP(ConfigManager*, config_manager_unref);
+void config_manager_free(ConfigManager *m);
+DEFINE_CLEANUP(ConfigManager*, config_manager_free);
 
 int set_config(KeyFile *key_file, const char *section, const char *k, const char *v);
+int set_config_uint(KeyFile *key_file, const char *section, const char *k, uint v);
 
 int add_key_to_section(Section *s, const char *k, const char *v);
-int add_key_to_section_integer(Section *s, const char *k, int v);
+int add_key_to_section_int(Section *s, const char *k, int v);
+int add_key_to_section_uint(Section *s, const char *k, uint v);
+
 int add_section_to_key_file(KeyFile *k, Section *s);
 
 const char *ctl_to_config(const ConfigManager *m, const char *name);
 
-int set_config_file_string(const char *path, const char *section, const char *k, const char *v);
+int set_config_file_str(const char *path, const char *section, const char *k, const char *v);
 int set_config_file_bool(const char *path, const char *section, const char *k, bool b);
-int set_config_file_integer(const char *path, const char *section, const char *k, int v);
+int set_config_file_int(const char *path, const char *section, const char *k, int v);
 
-int add_config_file_string(const char *path, const char *section, const char *k, const char *v);
+int add_config_file_str(const char *path, const char *section, const char *k, const char *v);
 
-int key_file_set_string(KeyFile *key_file, const char *section, const char *k, const char *v);
+int key_file_set_str(KeyFile *key_file, const char *section, const char *k, const char *v);
 int key_file_set_uint(KeyFile *key_file, const char *section, const char *k, const uint v);
 int key_file_set_bool(KeyFile *key_file, const char *section, const char *k, const bool b);
 
-int key_file_parse_string(KeyFile *key_file, const char *section, const char *k, char **v);
-int key_file_parse_integer(KeyFile *key_file, const char *section, const char *k, unsigned *v);
+int key_file_parse_str(KeyFile *key_file, const char *section, const char *k, char **v);
+int key_file_parse_int(KeyFile *key_file, const char *section, const char *k, unsigned *v);
 
-int key_file_add_string(KeyFile *key_file, const char *section, const char *k, const char *v);
-int add_key_to_section_string(const char *path, const char *section, const char *k, const char *v);
+int key_file_add_str(KeyFile *key_file, const char *section, const char *k, const char *v);
+int add_key_to_section_str(const char *path, const char *section, const char *k, const char *v);
 
 int remove_key_from_config_file(const char *path, const char *section, const char *k);
 int remove_key_value_from_config_file(const char *path, const char *section, const char *k, const char *v);
@@ -94,3 +97,5 @@ int read_conf_file(const char *path, char **s);
 int write_to_resolv_conf_file(char **dns, char **domains);
 
 int key_file_save(KeyFile *k);
+
+int determine_conf_file_name(const char *ifname, char **ret);
