@@ -18,6 +18,7 @@
 #include "macros.h"
 
 #define ETHER_ADDR_FORMAT_STR "%02X%02X%02X%02X%02X%02X"
+#define ETHER_ADDR_FORMAT_VAL(x) (x).ether_addr_octet[0], (x).ether_addr_octet[1], (x).ether_addr_octet[2], (x).ether_addr_octet[3], (x).ether_addr_octet[4], (x).ether_addr_octet[5]
 #define ETHER_ADDR_TO_STRING_MAX (3*6)
 
 #define parse_ether_address(mac) ether_aton(mac)
@@ -49,6 +50,8 @@ typedef struct IPAddress {
 
         int family;
         int prefix_len;
+        unsigned char scope;
+        unsigned char flags;
 
         char *label;
         char *lifetime;
